#
# spec file for package python3-gdata
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-gdata
Version:        2.0.18
Release:        4.17
Url:            http://code.google.com/p/gdata-python-client
Summary:        Python library to access data through Google Data APIs
License:        Apache-2.0
Group:          Development/Libraries/Python
Source:         http://gdata-python-client.googlecode.com/files/gdata-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  fdupes
BuildRequires:  python3-devel
BuildRequires:  python3-distribute
BuildArch:      noarch

%description
The Google data Python Client Library provides a library and source
code that make it easy to access data through Google Data APIs.

%prep
%setup -q -n gdata-%{version}
find samples/oauth samples/apps src/gdata -type f -name "*.py" -exec sed -i 's|\r||' {} \; # Fix wrong EOL encoding
find samples -type f -name "*.py" -exec chmod 0644 {} \; # Remove executable perms on samples
find samples -type f -name "*.txt" -exec chmod 0644 {} \; # Remove executable perms on samples
find samples -type f -name "*.c" -exec chmod 0644 {} \; # Remove executable perms on samples
# Remove unnecessary Python shebangs
find . -type f -exec sed -i -r '1s|^#! *(.+)/python(.*)$||' {} \;
find . -type f -exec sed -i -r '1s|^#! */usr/bin/env +python.*$||' {} \;

%build
python3 setup.py build

%install
python3 setup.py install --prefix="%{_prefix}" --root="%{buildroot}"
%fdupes %{buildroot}%{python3_sitelib}

%files
%defattr(-,root,root)
%doc README.txt RELEASE_NOTES.txt samples
%{python3_sitelib}/*

%changelog
* Sat Feb 14 2015 arun@gmx.de
- specfile:
  * update copyright year
  * add samples/app directory to find command that removes '\r's
  * also remove executable bit from *.txt and *.c files in samples/
- update to version 2.0.18:
  * Remove unused script.
  * Updated docs.
  * Bumped version.
  * Adding missing unit attributes for unit picing elements.
  * Fixing identifier_exists attribute for product items.
  * Fixing multipack attribute.
  * Adding new product spec attributes.
  * Update Sites Python API to allow page creation from a template
  * Adding an OAuth2Token subclass which can interact with
    google-api-python-client.
  * Modifying Content API for Shopping client to use schema
    projection.
  * Adding in ability to change Content for Shopping base URI via a
    kwarg for client constructor. (Fixes 6479060).
  * Adding paid clicks to Content API performance datapoint. (Issue
    6443130)
  * Adding support for adwords_accounts settings element in
    managedaccounts feed of Content API. (6443092)
  * Changing OAuth2 Authorization Header lead in from OAuth to Bearer
    (per http://goo.gl/QDiLZ). (issue 6455060)
  * Adding missing name XML attribute to
    gdata.contentforshopping.data.Group.
  * Renaming classes for inventory feed of Content API. (Issue
    6296085)
  * Updating offline URI for OAuth2 and explicity specifying
    approval_prompt as a kw arg. (Issue 6296072)
  * Added individual get for ManagedAccounts, functionality for paging
    and changed to correct endpoint. (issue 6304076)
  * Adding support for Local Products feed in Content API. (Issue
    6305091)
  * Adding support for wrong open search version hack on other
    ContentAPI Feed classes. (Issue 6296071)
  * Adding support for Data Quality Feed of Content API for
    Shopping. (Issue 6295074)
  * Adding back accidentally removed code from commit
    c92bc870e3a4363bed2732d50d782189407af7ac.
  * Adding support for Content API Users Feed. (Issue 6295071)
  * Adding custom id parser for Content API errors. (issue 6306073)
  * Adding support for product status elements in app:control for
    content for shopping. (Fixes 6299076)
- changes from version 2.0.17:
  * The gdata.youtube.service class now explicitly sets the
    GData-Version: 1 header, and is updated to use the correct
    ClientLogin URL.
  * Adding support for OAuth2 revoke endpoint.
  * Make Resource and ResourceFeed "Batch" compatible.
  * Forgot to add camelcase alias for batch in issue 5970062.
  * Adding support for performance data in Content API for Shopping
    (fixes Issue 5976061).
  * Added support for custom attributes in Content API for Shopping
    (fixes Issue 5970070).
  * Changed dest attrs in Content API to iterable, added validate_dest
    and fixed qname on app:control (fixes Issue 5976046).
  * Added camel case names to content API client public methods (fixes
    Issue 5970062).
  * Added support for Content for API errors on single and batch
    requests (fixes Issue 5971061).
  * Added support for start-token in Content API for Shopping (closes
    Issue 5980044).
  * Change gdata.docs.client.DocsClient.DeleteResource to use the
    entry instead of the link.
  * Allow for random kwargs in atom.client.AtomClient.request method.
  * Changing Shipping to list element in Content API for Shopping.
  * Fixing behavior in atom.http_core.Uri._get_query_string for query
    parameters with no parameter value (closes Issue 5938047).
  * Fixed batch function issues in content api for shopping client.
  * Updated GetFeed methods in the Email Settings API to return typed
    feeds
  * Namespace for channel element (in contentforshopping) was promoted
    from scp to sc.
  * Fixed release date year.
  * Fixing bug in recent change to the Email Settings API client
    library (rev. 194d0fd21fdd) + some typos
  * Updating the Email Settings API to return instances of the correct
    classes when retrieving settings
  * Added a sample to create a group and update its settings using the
    Groups Provisioning and Groups Settings APIs.
  * Added docs:description element to docs resources.
  * Fixed error in docs sample.
  * Added scopes for all Admin APIs in apps tag
  * Added a sample for Email Audit API demonstrating CRUD operations
    on email monitors
  * Fixed small doc errors, made tax a list element
  * Fix issues 590/591: Contact's gender XML element was wrong.
  * Added a sample marketplace application
  * Sample to delete obsolete suspended users
  * Sample to retrieve user's profile and contacts using 2LO
  * Fixing issue 587.  Wrong URL used for batch ACL changes.
  * Added a sample to list all the members of a group
  * Adding access_type=offline to OAuth 2.0 authorize URL.
  * Check document list entries have a content before trying to
    download them.
  * Added tag 2.0.16 for changeset c67f3c6398ba
  * Updated hgignore
  * Updated MANIFEST.in
  * Use a generated MANIFEST from MANIFEST.in
  * Updated release notes.
  * Fixed recording test, sometimes outside the US, google.com tries
    to redirect.
  * Updated pydocs
  * Bumped version string
  * Fixed doc generation script for my environment.
  * Added a sample to search users with a given pattern and and move
    them to an organization
* Fri Feb 22 2013 i@marguerite.su
- builds for python3
* Wed Mar 28 2012 vuntz@opensuse.org
- Update to version 2.0.16:
  + Add support for label deletion in the Email Settings API client
    library
  + Fix ACL batching URI in Docs.
  + Update RetrieveAllUsers and RetrieveAllAliases to return all
    pages instead of one.
  + Removing force=True from some ACL requests in DocsClient
  + Add RetrieveGroups method and updated RetrieveAllGroups and
    RetrieveAllMembers method
  + Add a client for organization unit provisioning
  + Add client architecture for group provisioning
  + Add client architecture for provisioning api and tests for
    client
  + Add support for batch requests to update spreadsheet cells.
  + Add GetAcl alias for get_acl in DocsClient
  + Add new ACL and get by ID methods to DocsClient.
  + Add some conditional imports for tlslite.
  + Updates to category handling for Documents list API
  + Add a function to retrieve all the aliases for a given user
    email.
  + Add test for RetrieveAllUserAliases and changed OAuth scopes
    for Apps
  + New and improved samples.
* Thu Nov 10 2011 saschpe@suse.de
- Update to version 2.0.15:
  * No upstream-provided changes
* Thu Jun  9 2011 saschpe@suse.de
- Remove shebang lines for files in Python sitelibdir instead of
  fixing their executable bit.
* Wed Jun  1 2011 saschpe@suse.de
- Update to version 2.0.14:
  * Fixed issues 456, 462, 482, 491, 493, 501
- Spec file cleanup:
  * Removed rpmlintrc and fixed warnings instead
  * Use fdupes for duplicates
* Tue Dec  7 2010 vuntz@opensuse.org
- Update to version 2.0.13:
  + Bug Fixes:
  - Correctly constructs queries based on categories for Blogger
    APIs.
  - YouTubeUserQuery constructor passes incorrect overridden
    parameter to base class.
  + Accept proxy username and password in http(s)_proxy environment
    variables.
  + Adding support for specifying URI to v3 docs client.
  + Adding tests for revisions for arbitrary file types in
    Documents List API.
  + Google Base, added bucket node to attributes.
  + Adding ContainsSampledData XML Element to Analytics Data Feed
    and updating samples
* Mon Sep 27 2010 vuntz@opensuse.org
- Update to version 2.0.12:
  + Bug Fixes:
  - PATCH request generates incorrect Content-Type
  - get_blog_name() does not correctly handle blog URLs
    containing hyphens
  - Packages should contain gdata.apps.audit in setup.py
  - Lots of memory usage when uploading big video files
  - gdata.contacts.client.ContactsClient.get_profiles_feed()
    broken
  + Turn on SSL be default for the spreadsheet API
  + Added support for new Analytics feeds
  + All V3 code and development has been out of this project and
    into http://code.google.com/p/google-api-python-client/
  + Added partial support for the YouTube API in v2
- Changes from version 2.0.11:
  + Added the following new APIs:
  - Apps Audit APIs
  - Apps Organization
  - Added Email Settings API client library v2.0
  + Fixes to file permissions for samples.
  + Fixing a broken calendar resource client from r983, removing a
    superfluous call to MakeResourceFeedUri(), adding regression
    tests for edit links.
  + Abstracting out AppsProperty so that it's usable by other libs.
  + Added optional change_password parameter to
    AppsService.CreateUser
  + Fixing minor bugs in analytics samples
  + Switch default connection type back to non-SSL connections.
  + Added OAuth test cases
  + Many APIs now use SSL, and some require it, so the following
    APIs now default to using HTTPS:
  - Spreadsheets
  - Sites
  - Calendar Resource
* Mon Sep  6 2010 vuntz@opensuse.org
- Fix build with python 2.7, by fixing a filename in the file list.
* Fri Aug  6 2010 vuntz@opensuse.org
- Update to version 2.0.10:
  + Add check for liveness of proxy in live tests. Also add in
    upload-diffs.py to make using codereview.appspot.com easier.
  + Add the ResourceEmail attribute to CalendarResourceEntry
  + Adding new single page methods to apps.groups.service.
  + Cleanup in service GetWithRetries.
  + Adding much more test coverage for calendar_resource.client.
  + Fixing Calendar Resource get_resource to use correct feed URI
    generator.
  + Adds support for Blogger Pages.
* Thu Mar 25 2010 vuntz@opensuse.org
- Update to version 2.0.9:
  + Fixed URL related bug in gdata.calendar.service. You can now
    edit and delete against https URLs.
  + Removed hard coded Python version from gdata.contacts.
- Changes from version 2.0.8:
  + Added support for resumable uploads with a sample that shows
    it's use with Google Docs.
  + Added the publish element and copy() method to the DocsClient.
  + Added support for the JSON-C data format recently released for
    the YouTube API.
  + Fixed import bug when using cryptomath with Python2.4 and
    lower.
  + Modified gdata.gauth to be usable under Python2.3.
  + Fixed errors which affect RetrieveAllEmailLists
    RetrieveEmailLists RetrieveAllRecipients RetrieveAllNicknames
    RetrieveNicknames RetrieveAllUsers in gdata.apps.service.
  + Fixed issues with contacts client returning a raw get and not a
    ContactEntry and a few auth_tokens are not being passed into
    the HTTP request.
  + Fixed issue parsing worksheet feed, entry was the wrong type,
    corrected to WorksheetEntry.
  + Fixed typo in gdata.spreadsheets.client (auth_service).
  + Fixed bug in Google Apps APIs UpdateSSOSettings.
  + The gdata.data.LinkFinder now looks in both the link and
    feed_link members for an ACL link.
  + Removed client side check on video type in YouTube service.
    Rely on the server to provide an error if the format is not
    supported.
  + Improved documentation for SpreadsheetsService's UpdateRow
    method to explain the use case it addresses and recomment
    alternatives.
  + Changed projecthosting to use the host member with relative
    URLs.
  + Added a get_headers function to be used in Python2.2 and 2.3
    since httplib.HTTPResponse does not have getheaders in those
    versions of Python.
  + Added a client smoke test to check version and auth related
    class members which all gdata.x.client's should have.
  + Updated the docs service_test.py to run as part of
    run_all_tests.py.
* Wed Jan 27 2010 vuntz@opensuse.org
- Update to version 2.0.7:
  - Added gdata.calendar_resource.client to support the management
    of calendar resources (like conference rooms) for Google Apps
    domains.
  - Updated the sites API client to use version 1.1 of the sites
    API.
  - Added support for 2 Legged OAuth to the GDClient and included a
    sample app.
  - Added a revoke_token method to GDClient to invalidate AuthSub
    or OAuth tokens.
  - Added a get_record method to the Spreadsheets client to fetch a
    single record entry.
  - Added includeSuspendedUsers parameter to the apps groups API.
  - Fixed a client login bug present in the Maps API client.
  - The client_id property in the YouTube service object is now
    optional.
  - Added optional 'feed' parameter to YouTube service's Query
    classes.
  - Updated tlslite's use of sha1 to use hashlib if using python2.5
    or higher.
  - Added a deadline parameter to gdata.alt.appengine to allow the
    urlfetch timeout to be modified to as high as 10 seconds.
  - Added GetGeneratorFromLinkFinder to GDataService which
    simplifies pagination across the entries in a feed.
  - Removed the default value for the test domain option.
  - Moved auth scopes to gdata.gauth from gdata.service.
* Thu Dec 24 2009 vuntz@opensuse.org
- Update to version 2.0.6:
  + updated the Google Analytics Data Export API to v2.
  + added support for batch operations on contacts and profiles.
  + added a DocsQuery class for the Documents List v3 API.
  + removed now obsolete ACL classes from gdata.docs.data in favor
    of using classes in gdata.acl.data.
  + fixed bug in querying group membership by email.
  + removed import which are not present in Python2.2 from
    gdata.service to maintain support for Python2.2.
  + added additional debug information to MockHttpClient.
* Thu Dec 17 2009 vuntz@opensuse.org
- Update to version 2.0.5:
  + Added new gdata.contacts.client (and data) which uses version
    3.0 of the contacts API.
  + Added new gdata.docs.client which uses version 3.0 of the
    Documents List API.
  + Added new v2 modules for the Analytics API
    (gdata.analytics.client).
  + Added conditional get using etags on get_entry.
  + Fixed bug in how Calendar redirect headers are handled when
    using this library in an App Engine app.
  + Added new Calendar XML elements to the gdata.calendar module.
  + Added v2 data model classes for finance, notebook,
    webmastertools, ACLs, opensearch and youtube.
  + Fixed issues with contacts.service when editing profiles.
  + Fixed bug in GDClient's get_next method.
  + Improved usability in Python2.3.
- Changes from version 2.0.4:
  + Added support for the project hosting issue tracker API.
  + Added a get-with-retries method to the v1 service for use with
    the Google Apps API to automatically retry.
  + Revised Google Sites client to use text input when creating a
    page.
  + Changed demo calendar in the Google Calendar API example.
- Changes from version 2.0.3:
  + Added support for Google Sites Data API.
  + Added support for Google Contacts profiles.
  + Added support for the Spreadsheets v3 API Tables feed and
    Records feed.
  + Added support for the Google Apps Admin Settings API.
  + New sample which illustrates use of the Blogger v1 API on App
    Engine using OAuth.
  + Added a new MediaSource for use with v2 data model classes.
  + The v2 client classes can now force all requests to be made
    over SSL.
  + Revised the test config system to allow test settings to be
    specified as command line arguments or prompt the user to enter
    them interactively.
  + Fixed UTF encoding issue in unittest on big endian
    architectures.
  + Fixed XML parsing bug in Spreadsheets data class.
  + Fixed bug in webmaster tools service verification method
    arguments.
  + Fixed download URL recognition in Document List Data API.
  + Some progress made in re-adding support for Python2.3.
- Changes from version 2.0.2:
  + Added support for the Google Maps Data API.
  + Added experimental data model classes for the v3 Spreadsheets API.
  + Auth token lookups when running in App Engine are now memcached
    which should improve efficiency.
  + Fixed a bug with the v2 HTTP proxy client. If behind a proxy,
    the full URL is now sent as the request selector.
  + Removed the gdata.client.GDataClient class which had been
    deprecated.
* Thu Sep 24 2009 aj@suse.de
- Use new python macros to fix build on openSUSE 11.2.
- build as noarch for 11.2 and newer.
* Fri Jul 31 2009 captain.magnus@opensuse.org
- Update to version 2.0.1:
  + Added support for Secure AuthSub, OAuth with HMAC and with RSA
    to the v2 auth code.
  + Added v2 data model classes for all XML elements in the gd
    namespace
  + Usability improvements in the gdata.docs.service module
  + Made the dependency on elementtree only required if you are
    using Python 2.4 and lower
  + Setting the ssl member in atom.service.AtomService will now
    override a URL which starts with http:
  + Added a proxy HTTP client which will use proxy environment
    variables to send all requests through the desired proxy server
    if present
  + Added user agent string indicating that this is from the gdata
    python v2 library
  + Removed unneeded title parameter from the Blogger client's
    add_comment method
  + Added an all_tests_local script which runs all tests except
    those which would make HTTP requests to remote servers
  + Added the birthday element to contacts entry, the reminder
    element to calendar events, and the method attribute to
    calendar's reminder class
  + The analytics GetData method no longer requires the dimenrions
    argument
- Update to version 2.0.0:
  + Released support for version 2 of the Google Data APIs
    protocol. To use the new version-aware code, use the
    gdata.client, atom.data, gdata.data modules and classes that
    derive from them. For example, use
    gdata.blogger.client.BloggerClient instead of
    gdata.blogger.service.BloggerService. High level, service
    specific classes are not available yet for other services, so
    feel free to migrate as they become available. The v1 service
    classes are still included so your existing code should be
    unaffected
  + Included new Blogger samples to illustrate v2 support, a
    command line demo and an app for App Engine
  + Added OAuth sample app which uses App Engine
  + Added the gCal:sequence element to CalendarEventEntry
  + Added two decorators to diaply warnings when deprecated methods
    are used
  + Added a login utility for command line samples to share to
    standardize the auth process on in a sample program
  + Fixed a bug in v2 XML parsing which prevented multiversion XML
    classes from correctly parsing and generating v2 code
  + Fixed v1 HTTP Host header settings, not default ports should
    now be included in the Host header
  + Fixed pickle error when an OAuth-RSA token is saved to the App
    Engine datastore
  + Fixed missing data in the Document List API unit tests
  + Improved backwards compatibility of v2 data model classes be
    adding aliases to v1 functions.
* Tue Jun  9 2009 vuntz@novell.com
- Update to version 1.3.3:
  + Added support for the Google Finance API.
  + The Google Data Service classes now support version 1.0a of the
    OAuth protocol.
  + Fixed a naming bug in unit tests for atom.service which
    appeared when using Python 2.6.x
  + Fixed URL parameter propogation when calling
    GDataService.Delete. The URL parameters are now preserved.
  + Fixed incorrect return type for gdata.FeedLinkFromString.
  + Added data model classes for the Atom and AtomPub XML elements
    which support version 2 of the Google Data APIs (by means of
    dynamic AtomPub namespace switching). The version 2 XML classes
    are much more backwards compatible with v1 classes than in
    previous releases.
* Sat May 23 2009 vuntz@novell.com
- Update to version 1.3.2:
  + Added support for the Google Analytics API.
  + Added support for the Google Book Search API.
  + Improved support for 2 legged OAuth and added a sample app.
  + Simplified the way an XML response from the server is parsed
    into the desired class for the version 2.0 API client
    (gdata.client.GDClient).
* Sat Apr 25 2009 vuntz@novell.com
- Update to version 1.3.1:
  + Fixed issues with setting the developer key in the YouTubeService
    constructor.
  + For the Document List API:
  - Added writersCanInvite element
  - Fixed a small errors in Document Entry
  - Added category label when creating different types of docs
  - Fixed DownLoad helpers which shouldn't write a file if server returns
    error.
  - Addied DocumentListEntryFromString converter and using
    DocumentListEntry class instead of GDataEntry class to create
    entries.
  + URLs in HTTP requests can now be unicode strings.
  + Improvements for the upcoming version 2.0.0 release:
  - The v2 auth code now support AuthSub and has been tested on
    App Engine.
  - Unit tests for the v2 client code will default to not use the
    local file cache but will make live requests unless cached
    responses is set to True in the test configuration module.
  - Older v1 unit tests can now use the v2 testing framework,
    migrated contacts API tests as a proof of concept. This will
    come in handy when testing backwards compatibility for the
    2.0 release.
  - Improved support for unicode and other character encodings in
    the v2 XML core module.
* Mon Mar 23 2009 vuntz@novell.com
- Update to version 1.3.0:
  + Added support for the Google Health API.
  + Added support for the groups management in the Google Apps
    Provisioning API.
  + Added the following new features for the Google Documents List
    API:
  - Folder create, move docs/folders in and out of other folders.
  - Suppport for modifications to Access Control Lists for
    documents.
  - Export functionality for documents, spreadsheets, and
    presentations.
  - Updated the docs_example.py sample app.
  - New new XML elements: resourceID, lastViewed, and
    lastModifiedBy.
  + Added ability to update web clip settings in the Google Apps
    email settigns API.
  + Fixed a bug in calendarExample that would cause execution to
    fail when an event attendee does not have any attendeeStatus
    data.
  + Fixed AuthSub request URLs which should be https.
  + Fixed logic when changing email settings when using the Google
    Apps API to only send properties which have been specified.
  + Includes a new and experimental client class
    (gdata.client.GDClient) which can be used with version two of
    the Google Data API protocol. This class may change in
    backwards incompatible ways before the 2.0.0 release, so use at
    your own risk.
- Remove AutoReqProv: it's default now.
- Remove check for old version of openSUSE.
- Do not set CFLAGS to the default value.
* Sun Feb  1 2009 mboman@suse.de
- Update to version 1.2.4:
  + Added a new AtomPubClient class
  + OAuth methods can now specify the desired OAuth server
  + Improved support for unicode strings in XML element
  + Fixed constructors for Service classes which inherit from GDataService
  + Added a 'contact_list' property to ContactsService
  + For Google Contacts, added a GetFeedUri method
  + New unit tests
* Wed Dec 24 2008 mboman@suse.de
- Update to version 1.2.3:
  + Added support for OAuth
  + Added support for Secure AuthSub
  + Added a new module for parsing XML
  + The Google Contacts API sample now pages through results.
  + Added phone number rel types using in the Google Contacts API.
  + The YouTube service module will use cElementTree if it is available.
  + Fixed typo in gdata.geo, changed longtitude to longitude but kept an
    alias for backwards compatibility.
  + Fixed Blogger's GetBlogId regular expressions to extract the ID from
    multiple kinds of entries.
  + Fixed type check in atom.http to allow unicode URL strings.
  + Added webmastertools test to the packaged download which fixed failures
    when running all data tests.
  + Improved compatibility of unit tests with Python2.3.
  + Added copies of tlslite and dependencies to support secure AuthSub and
    OAuth.
  + Changed the default host for Google Apps API requests to
    apps-apis.google.com.
* Fri Oct 24 2008 maw@suse.de
- Update to version 1.2.2:
  + Add support for the following APIs:
  * Google Apps Email Migration API
  * Google Apps Email Settings API
  * Google Webmaster Tools Data API
  * (Some modules for the above are not yet fully tested, so
    please file an issue if you notice something is not working
    as expected)
  + Restored support for gdata.http_request_handler when using App
    Engine to preserve backwards compatibility
  + Simplified auth token management by adding a current_token
    member to service classes; also added settings to control
    when the token_store is updated when using SetXToken() methods;
    the token_store will only be queried if there is no
    current_token
  + Fixed issue with requests to HTTPS URLs in which an AuthSub
    token was seen as invalid because the request contained the
    default port number (443); the library no longer includes the
    port in the Host header if it is using the default
  + Resolved issues with YouTube token scopes
  + Fixed issue which appeared when the Calendar API issues a
    redirect to a PUT request; the library now correctly retries
    with a PUT (instead of a POST)
  + Added workaround for differences in how the App Engine SDK
    handles redirects
  + Fixed typo in gdata.EntryLink declaration
  + Fixed invalid host errors seen when using some HTTP proxies.
* Fri Oct  3 2008 mboman@suse.de
- Update to version 1.2.1:
  + The gdata.alt.appengine module now replaces a Service object's token_store
    with an AppEngineTokenStore which automatically associates auth tokens
    with the current user and stores the auth tokens in the datastore.
  + Streamlined the gdata.auth module. There are now six recommended functions
    for using Google auth mechanisms. GDataService now uses these six
    functions.
  + Added an override_token in Service objects (AtomService, GDataService)
    which bypasses the token_store. This member is helpful when using a
    single use AuthSub token which is only valid for one request and so
    would not be reused.
  + gdata.alt.appengin.run_on_appengine will now return the modified Service
    object.
  + Fixed content length header issue in gdata.alt.appengine which caused
    errors when running on App Engine when HTTP headers are set to
    non-string values.
  + Fixed function naming issue in gdata.alt.appengine, a "private" function
    was not accessible in some import styles.
  + Fixed issue in atom.http which surfaces when passing in a string for the
    port number. Ports are now cast to ints.
  + Updated pydocs.
* Fri Sep 12 2008 maw@suse.de
- Update to version 1.2.0:
  + Refactored HTTP request mechanisms and the way that
    Authorization headers are created and applied to requests
  + Fixed issues with token string modification which caused
    certain AuthSub token values to become invalid
  + Created a new module for parsing and constructing URLs
    (atom.url).
  + Created a module for token storage which will lookup the
    correct auth token to be used for a particular URL.
  + Auth tokens are now represented as objects and contain
    information about the scopes (URLs) for which they can be
    used; the token object is responsible for adding the
    Authorization header to the request.
  + Added new functions to gdata.auth for extracting the raw
    token string from a response to an AuthSub token upgrade
    request
  + Added support for the location query parameter in YouTube
    queries
  + Added groups functionality to the Contacts API library
  + Batch request support added for Contacts API operations
  + Added default behavior to text_db GetTables: when no worksheet
    name or ID is specified, all tables are retrieved
  + Fixed client login for YouTube
  + Fixed issue in YouTube service when setting the developer
    key
  + Fixed bug in YouTube service which raised an exception when
    inserting a video using a file-like object
  + Added a method to Feed and Entry classes to find the
    "previous" link
  + A failure when attempting to upgrade a single use AuthSub
    token to a session token will now raise an exception
  + AppsForYourDomainException now uses Python2.5 style
    exception construction
  + Moved the logic for using this library on Google App Engine
    into a new module: gdata.alt.appengine.
* Mon Jun 30 2008 maw@suse.de
- Update to version 1.1.1:
  + Added support for the Google Contacts, YouTube, and
    Blogger APIs
  + Improved documentation
  + Various bug fixes.
* Thu Apr  3 2008 hpj@suse.de
- Upgraded to version 1.0.11.1:
  * Added text_db module to gdata.spreadsheet which makes using the
    Spreadsheets API feel more like using a simple database. This module
    streamlines use of the list feed.
  * Compatibility fixes for geo and photos modules to run on Python 2.2
    and 2.3.
  * Added the orderby parameter to gdata.service's Query class.
  * Changed the blogger sample to use orderby=updated so that queries on
    updated min or max will work.
  * Fix to string encoding in the atom core when converting text members
    to XML.
  * Modified the gdata.service.GDataService to include a handler member to
    which all HTTP requests are delegated. This will allow the underlying
    HTTP client to be swapped out and pave the way for use of a mock server
    in unit tests.
  * Fixed character encoding problems when parsing non ASCII XML.
  * Added pydocs for gdata's geo, exif, and media packages.
* Wed Jan 16 2008 jpr@suse.de
- Initial checkin, based roughly on devel:languages:python, but with
  new version.  No patches to review and clean tarball download.
